Class: Cuprum::Cli::Dependencies::SystemCommand::CapturedOutput

Inherits:
Data
  • Object
show all
Defined in:
lib/cuprum/cli/dependencies/system_command.rb

Overview

Data object representing the captured output and status of a process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#errorObject (readonly)

Returns the value of attribute error

Returns:

  • (Object)

    the current value of error



14
15
16
# File 'lib/cuprum/cli/dependencies/system_command.rb', line 14

def error
  @error
end

#outputObject (readonly)

Returns the value of attribute output

Returns:

  • (Object)

    the current value of output



14
15
16
# File 'lib/cuprum/cli/dependencies/system_command.rb', line 14

def output
  @output
end

#statusObject (readonly)

Returns the value of attribute status

Returns:

  • (Object)

    the current value of status



14
15
16
# File 'lib/cuprum/cli/dependencies/system_command.rb', line 14

def status
  @status
end

Instance Method Details

#success?true, false

Returns true if the process was successful, otherwise false.

Returns:

  • (true, false)

    true if the process was successful, otherwise false.



17
# File 'lib/cuprum/cli/dependencies/system_command.rb', line 17

def success? = status.success?