Class: Cuprum::Cli::Dependencies::SystemCommand::Mock::MockStatus

Inherits:
Data
  • Object
show all
Defined in:
lib/cuprum/cli/dependencies/system_command/mock.rb

Overview

Data class providing a mock implementation of Process::Status.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#exitstatusObject (readonly)

Returns the value of attribute exitstatus

Returns:

  • (Object)

    the current value of exitstatus



9
10
11
# File 'lib/cuprum/cli/dependencies/system_command/mock.rb', line 9

def exitstatus
  @exitstatus
end

Instance Method Details

#success?true, false

Returns true if the exit status is zero, otherwise false.

Returns:

  • (true, false)

    true if the exit status is zero, otherwise false.



11
# File 'lib/cuprum/cli/dependencies/system_command/mock.rb', line 11

def success? = exitstatus.zero?