Class: Cuprum::Cli::Dependencies::SystemCommand::CapturedOutput
- Inherits:
-
Data
- Object
- Data
- Cuprum::Cli::Dependencies::SystemCommand::CapturedOutput
- Defined in:
- lib/cuprum/cli/dependencies/system_command.rb
Overview
Data object representing the captured output and status of a process.
Instance Attribute Summary collapse
-
#error ⇒ Object
readonly
Returns the value of attribute error.
-
#output ⇒ Object
readonly
Returns the value of attribute output.
-
#status ⇒ Object
readonly
Returns the value of attribute status.
Instance Method Summary collapse
-
#success? ⇒ true, false
True if the process was successful, otherwise false.
Instance Attribute Details
#error ⇒ Object (readonly)
Returns the value of attribute error
14 15 16 |
# File 'lib/cuprum/cli/dependencies/system_command.rb', line 14 def error @error end |
#output ⇒ Object (readonly)
Returns the value of attribute output
14 15 16 |
# File 'lib/cuprum/cli/dependencies/system_command.rb', line 14 def output @output end |
#status ⇒ Object (readonly)
Returns the value of attribute status
14 15 16 |
# File 'lib/cuprum/cli/dependencies/system_command.rb', line 14 def status @status end |
Instance Method Details
#success? ⇒ true, false
Returns true if the process was successful, otherwise false.
17 |
# File 'lib/cuprum/cli/dependencies/system_command.rb', line 17 def success? = status.success? |