Class: Cuprum::Cli::Dependencies::SystemCommand::Mock::MockStatus
- Inherits:
-
Data
- Object
- Data
- Cuprum::Cli::Dependencies::SystemCommand::Mock::MockStatus
- Defined in:
- lib/cuprum/cli/dependencies/system_command/mock.rb
Overview
Data class providing a mock implementation of Process::Status.
Instance Attribute Summary collapse
-
#exitstatus ⇒ Object
readonly
Returns the value of attribute exitstatus.
Instance Method Summary collapse
-
#success? ⇒ true, false
True if the exit status is zero, otherwise false.
Instance Attribute Details
#exitstatus ⇒ Object (readonly)
Returns the value of attribute exitstatus
9 10 11 |
# File 'lib/cuprum/cli/dependencies/system_command/mock.rb', line 9 def exitstatus @exitstatus end |
Instance Method Details
#success? ⇒ true, false
Returns true if the exit status is zero, otherwise false.
11 |
# File 'lib/cuprum/cli/dependencies/system_command/mock.rb', line 11 def success? = exitstatus.zero? |