Class: Cuprum::Cli::Errors::Files::TemplateNotResolved
- Inherits:
-
TemplateError
- Object
- Error
- TemplateError
- Cuprum::Cli::Errors::Files::TemplateNotResolved
- Defined in:
- lib/cuprum/cli/errors/files/template_not_resolved.rb
Overview
Error returned when unable to resolve a template for a templated file.
Constant Summary collapse
- TYPE =
Short string used to identify the type of error.
'cuprum.cli.errors.files.template_not_resolved'
Instance Attribute Summary collapse
-
#file_path ⇒ String
readonly
The file path for the templated file.
-
#options ⇒ Hash
readonly
Options used when attempting to resolve the template.
Attributes inherited from TemplateError
Instance Method Summary collapse
-
#initialize(file_path:, details: nil, message: nil, options: {}) ⇒ TemplateNotResolved
constructor
A new instance of TemplateNotResolved.
Constructor Details
#initialize(file_path:, details: nil, message: nil, options: {}) ⇒ TemplateNotResolved
Returns a new instance of TemplateNotResolved.
17 18 19 20 21 22 |
# File 'lib/cuprum/cli/errors/files/template_not_resolved.rb', line 17 def initialize(file_path:, details: nil, message: nil, options: {}) @file_path = file_path @options = super(details:, file_path:, message: (), options:) end |
Instance Attribute Details
#file_path ⇒ String (readonly)
Returns the file path for the templated file.
25 26 27 |
# File 'lib/cuprum/cli/errors/files/template_not_resolved.rb', line 25 def file_path @file_path end |
#options ⇒ Hash (readonly)
Returns options used when attempting to resolve the template.
28 29 30 |
# File 'lib/cuprum/cli/errors/files/template_not_resolved.rb', line 28 def @options end |