Class: Cuprum::Cli::Errors::SystemCommandFailure
- Inherits:
-
Error
- Object
- Error
- Cuprum::Cli::Errors::SystemCommandFailure
- Defined in:
- lib/cuprum/cli/errors/system_command_failure.rb
Overview
Error returned when a system command returns a non-success status.
Constant Summary collapse
- TYPE =
Short string used to identify the type of error.
'cuprum.cli.errors.system_command_failure'
Instance Attribute Summary collapse
-
#command ⇒ Object
readonly
Returns the value of attribute command.
-
#details ⇒ Object
readonly
Returns the value of attribute details.
-
#exit_status ⇒ Object
readonly
Returns the value of attribute exit_status.
Instance Method Summary collapse
-
#initialize(command:, details: nil, exit_status: nil) ⇒ SystemCommandFailure
constructor
A new instance of SystemCommandFailure.
Constructor Details
#initialize(command:, details: nil, exit_status: nil) ⇒ SystemCommandFailure
Returns a new instance of SystemCommandFailure.
16 17 18 19 20 21 22 |
# File 'lib/cuprum/cli/errors/system_command_failure.rb', line 16 def initialize(command:, details: nil, exit_status: nil) @command = command @details = details @exit_status = exit_status super(message: ) end |
Instance Attribute Details
#command ⇒ Object (readonly)
Returns the value of attribute command.
24 25 26 |
# File 'lib/cuprum/cli/errors/system_command_failure.rb', line 24 def command @command end |
#details ⇒ Object (readonly)
Returns the value of attribute details.
26 27 28 |
# File 'lib/cuprum/cli/errors/system_command_failure.rb', line 26 def details @details end |
#exit_status ⇒ Object (readonly)
Returns the value of attribute exit_status.
28 29 30 |
# File 'lib/cuprum/cli/errors/system_command_failure.rb', line 28 def exit_status @exit_status end |